

set -ex



test -f ${PREFIX}/include/avif/avif.h
test -f ${PREFIX}/lib/libavif${SHLIB_EXT}
test -f ${PREFIX}/lib/libavif.so.15
test -f ${PREFIX}/lib/libavif.so.15.0.1
test -f ${PREFIX}/lib/pkgconfig/libavif.pc
test -f ${PREFIX}/lib/cmake/libavif/libavif-config.cmake
test -f ${PREFIX}/lib/cmake/libavif/libavif-config-release.cmake
test -f ${PREFIX}/lib/cmake/libavif/libavif-config-version.cmake
exit 0
